@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0504';
+our $VERSION = '0.0600';
 
 use Moo;
 use strictures 2;
@@ -262,6 +262,36 @@ sub comprnd {
 }
 
 
+sub count_ones {
+    my ($self, $n) = @_;
+    my $x = 0;
+    if (ref $n) {
+        for my $i (@$n) {
+            $x++ if $i == 1;
+        }
+    }
+    else {
+        $x = $n =~ tr/1//;
+    }
+    return $x;
+}
+
+
+sub count_zeros {
+    my ($self, $n) = @_;
+    my $x = 0;
+    if (ref $n) {
+        for my $i (@$n) {
+            $x++ if $i == 0;
+        }
+    }
+    else {
+        $x = $n =~ tr/0//;
+    }
+    return $x;
+}
+
+
 sub de_bruijn {
     my ($self, $n) = @_;
     my $sequence = $n ? debruijn([1,0], $n) : 0;
@@ -569,7 +599,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0504
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -730,6 +760,28 @@ Example:
 
   $got = $mcr->comprnd(16); # [1,3,2,1,1,2,1,3,2], etc.
 
+=head2 count_ones
+
+  $count = $mcr->count_ones($n);
+
+Count the number of 1s in a string or vector.
+
+Examples:
+
+  $got = $mcr->count_ones('100110100');         # 4
+  $got = $mcr->count_ones([1,0,0,1,1,0,1,0,0]); # 4
+
+=head2 count_zeros
+
+  $count = $mcr->count_zeros($n);
+
+Count the number of 0s in a string or vector.
+
+Examples:
+
+  $got = $mcr->count_zeros('100110100');         # 5
+  $got = $mcr->count_zeros([1,0,0,1,1,0,1,0,0]); # 5
+
 =head2 de_bruijn
 
   $sequence = $mcr->de_bruijn($n);
